@@ -1,5 +1,5 @@
 package Incunabulum::Config;
-#Id#
+#$Id: Config.pm 24 2007-07-07 21:07:58Z apeiron $
 use strict;
 use warnings FATAL => 'all';
 
@@ -8,9 +8,9 @@ use vars qw#@EXPORT @EXPORT_OK#;
 
 use Module::Pluggable::Ordered;
 
-our @EXPORT = qw#do_config write_config#;
+our @EXPORT = qw#do_config#;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 my $config;
 
@@ -18,12 +18,7 @@ sub do_config
 {
 	my $pkg = shift;
 	$config = shift;
-	Incunabulum::Config->call_plugins('get_config_data');
-}
-
-sub write_config
-{
-	$config = +shift;
+	Incunabulum::Config->call_plugins('get_config_data', \$config);
 }
 
 sub get_config_tree
